package com.mt.wms.empty.controller;

import com.mt.wms.core.base.BaseController;
import com.mt.wms.core.constants.CommonConstant;
import com.mt.wms.core.params.IdParam;
import com.mt.wms.core.validator.groups.PageGroup;
import com.mt.wms.core.vo.PageVo;
import com.mt.wms.core.vo.R;
import com.mt.wms.empty.params.OrderParamForApms;
import com.mt.wms.empty.params.OrderInfoBasePageParam;
import com.mt.wms.empty.params.OrderInfoPersonCreateParam;
import com.mt.wms.empty.params.OrderInfoTaskDetParam;
import com.mt.wms.empty.service.OrderInfoService;
import com.mt.wms.empty.vo.OrderInfoTaskDetVo;
import com.mt.wms.empty.vo.OrderInfoVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.groups.Default;

/**
 * @author xcc
 * @date 2021年11月8日
 * @since 1.0
 */
@RestController
@RequestMapping(CommonConstant.API_MODULE_BASE + "orderInfo")
@Slf4j
@Api(value = "订单管理", tags = "订单管理", hidden = false)
public class OrderInfoController extends BaseController {
    @Autowired
    private OrderInfoService orderInfoService;

    @PostMapping(value = "apmsPostOrder")
    @ApiOperation(value = "接收apms推送订单信息")
    private R apmsPostOrder(@Validated @RequestBody OrderParamForApms apmsPostOrderParam) {
        return orderInfoService.apmsPostOrder(apmsPostOrderParam);
    }

    @PostMapping(value = "page")
    @ApiOperation(value = "获取分页报警基础信息")
    private R<PageVo<OrderInfoVo>> page(@Validated({PageGroup.class, Default.class}) @RequestBody OrderInfoBasePageParam orderBaseParam) {
        return orderInfoService.page(orderBaseParam);
    }

    @PostMapping(value = "personCreateOrder")
    @ApiOperation(value = "人工创建订单信息")
    private R personCreateOrder(@Validated({Default.class}) @RequestBody OrderInfoPersonCreateParam orderInfoPersonCreateParam) {
        return orderInfoService.personCreateOrder(orderInfoPersonCreateParam);
    }
    @PostMapping(value = "get")
    @ApiOperation(value = "当前订单查看详情")
    private R<OrderInfoVo> get(@Validated @RequestBody IdParam idParam) {
        return orderInfoService.getOne(idParam);
    }
    @PostMapping(value = "getTaskInfo")
    @ApiOperation(value = "当前订单任务详情")
    private R<PageVo<OrderInfoTaskDetVo>> getTaskInfo(@Validated @RequestBody OrderInfoTaskDetParam orderInfoTaskDetParam) {
        return orderInfoService.getTaskInfo(orderInfoTaskDetParam);
    }
}
