package com.mt.wms.empty.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mt.wms.core.base.BaseService;
import com.mt.wms.core.dal.entity.OrderInfo;
import com.mt.wms.core.dal.service.OrderInfoServiceBiz;
import com.mt.wms.core.params.IdParam;
import com.mt.wms.core.vo.PageVo;
import com.mt.wms.core.vo.R;
import com.mt.wms.empty.enums.OrderSourceEnum;
import com.mt.wms.empty.params.OrderParamForApms;
import com.mt.wms.empty.params.OrderInfoBasePageParam;
import com.mt.wms.empty.params.OrderInfoPersonCreateParam;
import com.mt.wms.empty.params.OrderInfoTaskDetParam;
import com.mt.wms.empty.service.CurrTaskDetService;
import com.mt.wms.empty.service.OrderInfoService;
import com.mt.wms.empty.vo.OrderInfoTaskDetVo;
import com.mt.wms.empty.vo.OrderInfoVo;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * xx服务实现类
 *
 * @author xcc
 * @date 2021年11月8日
 * @since 1.0
 */
@Service
@Transactional
public class OrderInfoServiceImpl extends BaseService implements OrderInfoService {

    @Autowired
    OrderInfoServiceBiz orderInfoService;

    @Autowired
    CurrTaskDetService currTaskDetService;


    @Override
    public R apmsPostOrder(OrderParamForApms apmsPostOrderParam) {
        OrderInfo orderInfo = new OrderInfo();
        BeanUtils.copyProperties(apmsPostOrderParam,orderInfo);
        setCommonField(orderInfo);
        //设定来源信息为apms
        orderInfo.setOrderSource(OrderSourceEnum.APMS.getValue());
        orderInfo.setInterCode("APMS"+System.currentTimeMillis());
        orderInfoService.save(orderInfo);
        //todo 记录通讯日志信息
        return successful("Wms接收Apms订单成功。");
    }

    @Override
    public R<PageVo<OrderInfoVo>> page(OrderInfoBasePageParam param) {
        QueryWrapper<OrderInfo> wrapper=new QueryWrapper<>();
        wrapper.like(StringUtils.isNotBlank(param.getIdenCardNum()),OrderInfo.IDEN_CARD_NUM, param.getIdenCardNum())
                .like(StringUtils.isNotBlank(param.getOrderNo()),OrderInfo.ORDER_NO, param.getOrderNo())
                .eq(OrderInfo.VALID,1)
                .orderByDesc(OrderInfo.CREATE_TIME);
        Page<OrderInfo> page = orderInfoService.page(new Page<>(param.getCurrent(), param.getSize()), wrapper);
        return successful(new PageVo<>(page,OrderInfoVo.class));
    }

    @Override
    public R personCreateOrder(OrderInfoPersonCreateParam orderInfoPersonCreateParam) {
        OrderInfo orderInfo = new OrderInfo();
        BeanUtils.copyProperties(orderInfoPersonCreateParam,orderInfo);
        setCommonField(orderInfo);
        //设定来源信息为人工
        orderInfo.setOrderSource(OrderSourceEnum.PERSON.getValue());
        orderInfo.setInterCode("PERSONAL"+System.currentTimeMillis());
        orderInfoService.save(orderInfo);
        return successful("人工创建订单成功。");
    }

    @Override
    public R<OrderInfoVo> getOne(IdParam idParam) {
        OrderInfo byId = orderInfoService.getById(idParam.getId());
        OrderInfoVo build = OrderInfoVo.builder().build();
        BeanUtils.copyProperties(byId,build);
        return successful(build);
    }


    /**
     * todo 获取详细的拆分任务信息
      */
    @Override
    public R<PageVo<OrderInfoTaskDetVo>> getTaskInfo(OrderInfoTaskDetParam param) {
        //从任务详细中获取该标识卡和订单的所有订单
        PageVo<OrderInfoTaskDetVo> currOrderCurrTask = currTaskDetService.getCurrOrderCurrTask(param);
        //获取车辆信息
        //获取库位信息
        //获取窑炉信息
        currOrderCurrTask.getRecords().forEach(orderInfo ->
                {

                }
        );
        return null;
    }
}
